@@ -10,20 +10,20 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'BINDIR': '/usr/local/bin',
  'BINLIBDEST': '/usr/local/lib/python2.7',
  'BLDLIBRARY': '-L. -lpython2.7',
- 'BLDSHARED': 'cc -shared -lpthread -L/usr/local/lib -Wl,-rpath,/usr/local/lib -pie -Wl,-z,relro -Wl,-z,now -fstack-protector',
+ 'BLDSHARED': 'cc -shared -lpthread -L/usr/local/lib -Wl,-rpath,/usr/local/lib -pie -Wl,-z,relro -Wl,-z,now -fstack-protector-all',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'CC': 'cc',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-fno-strict-aliasing -O2 -pipe  -fPIE -fPIC -fstack-protector-all -fno-strict-aliasing -DNDEBUG',
+ 'CFLAGS': '-fno-strict-aliasing -O2 -pipe  -DHARDENEDBSD -fPIE -fPIC -fstack-protector-all -fno-strict-aliasing  -DNDEBUG',
  'CFLAGSFORSHARED': '-fPIC',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
- 'CONFIG_ARGS': "'--enable-shared' '--without-pydebug' '--enable-ipv6' '--with-system-ffi' '--with-pymalloc' '--with-threads' '--enable-unicode=ucs4' '--prefix=/usr/local' '--localstatedir=/var' '--mandir=/usr/local/man' '--infodir=/usr/local/info/' '--build=amd64-portbld-freebsd11.1' 'build_alias=amd64-portbld-freebsd11.1' 'CC=cc' 'CFLAGS=-O2 -pipe  -fPIE -fPIC -fstack-protector-all -fno-strict-aliasing' 'LDFLAGS= -lpthread -L/usr/local/lib -Wl,-rpath,/usr/local/lib -pie -Wl,-z,relro -Wl,-z,now -fstack-protector' 'LIBS=' 'CPPFLAGS=-I/usr/local/include' 'CPP=cpp' 'PKG_CONFIG=pkgconf'",
+ 'CONFIG_ARGS': "'--enable-shared' '--without-pydebug' '--enable-ipv6' '--with-system-ffi' '--with-pymalloc' '--with-threads' '--enable-unicode=ucs4' '--prefix=/usr/local' '--localstatedir=/var' '--mandir=/usr/local/man' '--infodir=/usr/local/share/info/' '--build=amd64-portbld-freebsd11.2' 'build_alias=amd64-portbld-freebsd11.2' 'CC=cc' 'CFLAGS=-O2 -pipe  -DHARDENEDBSD -fPIE -fPIC -fstack-protector-all -fno-strict-aliasing ' 'LDFLAGS= -lpthread -L/usr/local/lib -Wl,-rpath,/usr/local/lib -pie -Wl,-z,relro -Wl,-z,now -fstack-protector-all ' 'LIBS=' 'CPPFLAGS=-I/usr/local/include' 'CPP=cpp' 'PKG_CONFIG=pkgconf'",
  'CONFINCLUDEDIR': '/usr/local/include',
  'CONFINCLUDEPY': '/usr/local/include/python2.7',
  'COREPYTHONPATH': ':plat-freebsd11:lib-tk:lib-old',
- 'COVERAGE_INFO': '/usr/obj/usr/ports/lang/python27/work/Python-2.7.15/coverage.info',
- 'COVERAGE_REPORT': '/usr/obj/usr/ports/lang/python27/work/Python-2.7.15/lcov-report',
+ 'COVERAGE_INFO': '/usr/obj/usr/ports/lang/python27/work/Python-2.7.16/coverage.info',
+ 'COVERAGE_REPORT': '/usr/obj/usr/ports/lang/python27/work/Python-2.7.16/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov report"',
  'CPPFLAGS': '-I. -IInclude -I./Include -I/usr/local/include',
  'CXX': 'c++',
@@ -187,10 +187,9 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_LANGINFO_H': 1,
  'HAVE_LARGEFILE_SUPPORT': 0,
  'HAVE_LCHFLAGS': 1,
- 'HAVE_LCHMOD': 1,
  'HAVE_LCHOWN': 1,
  'HAVE_LGAMMA': 1,
- 'HAVE_LIBDL': 0,
+ 'HAVE_LIBDL': 1,
  'HAVE_LIBDLD': 0,
  'HAVE_LIBIEEE': 0,
  'HAVE_LIBINTL_H': 0,
@@ -357,7 +356,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'amd64-portbld-freebsd11.1',
+ 'HOST_GNU_TYPE': 'amd64-portbld-freebsd11.2',
  'HURD_C_THREADS': 0,
  'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include /usr/local/include/python2.7 /usr/local/include/python2.7',
  'INCLUDEDIR': '/usr/local/include',
@@ -369,11 +368,11 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'INSTALL_SHARED': '/usr/bin/install -c -m 555',
  'INSTSONAME': 'libpython2.7.so.1',
  'LDCXXSHARED': 'c++ -shared',
- 'LDFLAGS': '-lpthread -L/usr/local/lib -Wl,-rpath,/usr/local/lib -pie -Wl,-z,relro -Wl,-z,now -fstack-protector',
+ 'LDFLAGS': '-lpthread -L/usr/local/lib -Wl,-rpath,/usr/local/lib -pie -Wl,-z,relro -Wl,-z,now -fstack-protector-all',
  'LDLAST': '',
  'LDLIBRARY': 'libpython2.7.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'cc -shared -lpthread -L/usr/local/lib -Wl,-rpath,/usr/local/lib -pie -Wl,-z,relro -Wl,-z,now -fstack-protector',
+ 'LDSHARED': 'cc -shared -lpthread -L/usr/local/lib -Wl,-rpath,/usr/local/lib -pie -Wl,-z,relro -Wl,-z,now -fstack-protector-all',
  'LIBC': '',
  'LIBDEST': '/usr/local/lib/python2.7',
  'LIBDIR': '/usr/local/lib',
@@ -386,7 +385,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'LIBPL': '/usr/local/lib/python2.7/config',
  'LIBRARY': 'libpython2.7.a',
  'LIBRARY_OBJS': '\\',
- 'LIBS': '-lutil',
+ 'LIBS': '-ldl  -lutil',
  'LIBSUBDIRS': 'lib-tk lib-tk/test lib-tk/test/test_tkinter \\',
  'LINKCC': 'cc',
  'LINKFORSHARED': '-Wl,--export-dynamic',
@@ -453,7 +452,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PYTHON_FOR_REGEN': 'python3',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-fno-strict-aliasing -O2 -pipe  -fPIE -fPIC -fstack-protector-all -fno-strict-aliasing -DNDEBUG -I. -IInclude -I./Include -I/usr/local/include -fPIC -DPy_BUILD_CORE',
+ 'PY_CFLAGS': '-fno-strict-aliasing -O2 -pipe  -DHARDENEDBSD -fPIE -fPIC -fstack-protector-all -fno-strict-aliasing  -DNDEBUG -I. -IInclude -I./Include -I/usr/local/include -fPIC -DPy_BUILD_CORE',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_UNICODE_TYPE': 0,
@@ -465,12 +464,12 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'RANLIB': 'ranlib',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/usr/ports/lang/python27/work/Python-2.7.15',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/usr/ports/lang/python27/work/Python-2.7.16',
  'SCRIPTDIR': '/usr/local/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '',
  'SHELL': '/bin/sh',
- 'SHLIBS': '-lutil',
+ 'SHLIBS': '-ldl  -lutil',
  'SHLIB_EXT': '".so"',
  'SIGNAL_OBJS': '',
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
@@ -508,7 +507,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'TESTOPTS': '-l',
  'TESTPATH': '',
  'TESTPROG': './Lib/test/regrtest.py',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/usr/ports/lang/python27/work/Python-2.7.15 ./python -Wd -3 -E -tt',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/usr/ports/lang/python27/work/Python-2.7.16 ./python -Wd -3 -E -tt',
  'TESTPYTHONOPTS': '',
  'THREADOBJ': 'Python/thread.o',
  'TIME_WITH_SYS_TIME': 1,
@@ -533,11 +532,11 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/obj/usr/ports/lang/python27/work/Python-2.7.15',
- 'abs_srcdir': '/usr/obj/usr/ports/lang/python27/work/Python-2.7.15',
- 'build': 'amd64-portbld-freebsd11.1',
+ 'abs_builddir': '/usr/obj/usr/ports/lang/python27/work/Python-2.7.16',
+ 'abs_srcdir': '/usr/obj/usr/ports/lang/python27/work/Python-2.7.16',
+ 'build': 'amd64-portbld-freebsd11.2',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
- 'host': 'amd64-portbld-freebsd11.1',
+ 'host': 'amd64-portbld-freebsd11.2',
  'prefix': '/usr/local',
  'srcdir': '.'}
