@@ -12,7 +12,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'BINLIBDEST': '/usr/local/lib/python3.7',
  'BLDLIBRARY': '-L. -lpython3.7m',
  'BLDSHARED': 'cc -pthread -shared -L/usr/local/lib -Wl,-rpath,/usr/local/lib '
-              '-pie -Wl,-z,relro -Wl,-z,now -fstack-protector',
+              '-pie -Wl,-z,relro -Wl,-z,now -fstack-protector-all',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'amd64-portbld-freebsd11.2',
@@ -42,13 +42,14 @@ build_time_vars = {'ABIFLAGS': 'm',
                 '-pipe  -DHARDENEDBSD -fPIE -fPIC -fstack-protector-all '
                 "-fno-strict-aliasing ' 'LDFLAGS= -L/usr/local/lib "
                 '-Wl,-rpath,/usr/local/lib -pie -Wl,-z,relro -Wl,-z,now '
-                "-fstack-protector ' 'LIBS=' 'CPPFLAGS=-I/usr/local/include' "
-                "'CPP=cpp' 'PKG_CONFIG=pkgconf'",
+                "-fstack-protector-all ' 'LIBS=' "
+                "'CPPFLAGS=-I/usr/local/include' 'CPP=cpp' "
+                "'PKG_CONFIG=pkgconf'",
  'CONFINCLUDEDIR': '/usr/local/include',
  'CONFINCLUDEPY': '/usr/local/include/python3.7m',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/usr/obj/usr/ports/lang/python37/work/Python-3.7.3/coverage.info',
- 'COVERAGE_REPORT': '/usr/obj/usr/ports/lang/python37/work/Python-3.7.3/lcov-report',
+ 'COVERAGE_INFO': '/usr/obj/usr/ports/lang/python37/work/Python-3.7.4/coverage.info',
+ 'COVERAGE_REPORT': '/usr/obj/usr/ports/lang/python37/work/Python-3.7.4/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -I/usr/local/include',
@@ -508,13 +509,13 @@ build_time_vars = {'ABIFLAGS': 'm',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'c++ -pthread -shared',
  'LDFLAGS': '-L/usr/local/lib -Wl,-rpath,/usr/local/lib -pie -Wl,-z,relro '
-            '-Wl,-z,now -fstack-protector',
+            '-Wl,-z,now -fstack-protector-all',
  'LDFLAGS_NODIST': '',
  'LDLAST': '',
  'LDLIBRARY': 'libpython3.7m.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'cc -pthread -shared -L/usr/local/lib -Wl,-rpath,/usr/local/lib '
-             '-pie -Wl,-z,relro -Wl,-z,now -fstack-protector',
+             '-pie -Wl,-z,relro -Wl,-z,now -fstack-protector-all',
  'LDVERSION': '3.7m',
  'LIBC': '',
  'LIBDEST': '/usr/local/lib/python3.7',
@@ -636,11 +637,11 @@ build_time_vars = {'ABIFLAGS': 'm',
                    '-Werror=implicit-function-declaration -I. -I./Include '
                    '-I/usr/local/include -fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-L/usr/local/lib -Wl,-rpath,/usr/local/lib -pie '
-                    '-Wl,-z,relro -Wl,-z,now -fstack-protector',
+                    '-Wl,-z,relro -Wl,-z,now -fstack-protector-all',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/local/include',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-L/usr/local/lib -Wl,-rpath,/usr/local/lib -pie -Wl,-z,relro '
-               '-Wl,-z,now -fstack-protector',
+               '-Wl,-z,now -fstack-protector-all',
  'PY_LDFLAGS_NODIST': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
@@ -658,7 +659,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/usr/ports/lang/python37/work/Python-3.7.3',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/usr/ports/lang/python37/work/Python-3.7.4',
  'SCRIPTDIR': '/usr/local/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '@SGI_ABI@',
@@ -686,7 +687,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-37m',
- 'SRCDIRS': 'Parser Objects Python Modules Programs',
+ 'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
@@ -700,10 +701,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/usr/ports/lang/python37/work/Python-3.7.3 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/usr/ports/lang/python37/work/Python-3.7.4 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/obj/usr/ports/lang/python37/work/Python-3.7.3 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/obj/usr/ports/lang/python37/work/Python-3.7.4 '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -724,8 +725,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/obj/usr/ports/lang/python37/work/Python-3.7.3',
- 'abs_srcdir': '/usr/obj/usr/ports/lang/python37/work/Python-3.7.3',
+ 'abs_builddir': '/usr/obj/usr/ports/lang/python37/work/Python-3.7.4',
+ 'abs_srcdir': '/usr/obj/usr/ports/lang/python37/work/Python-3.7.4',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
  'prefix': '/usr/local',
